@@ -8,8 +8,6 @@
 import os
 import fs
 import fs.zipfs
-import six
-import time
 import json
 import furl
 import tempfile
@@ -41,15 +39,14 @@ LOG = logging.getLogger('xmldirector.connector')
 
 
 def safe_unicode(s):
-    if not isinstance(s, six.text_type):
-        return six.text_type(s, 'utf8')
+    if not isinstance(s, str):
+        return s.decode("utf8")
     return s
 
 
 @implementer(IStreamIterator)
 class connector_iterator():
     """ Iterator for pyfilesystem content """
-
     def __init__(self, handle, filename, mode='rb', streamsize=1 << 24):
         self.handle = handle
         self.fp = handle.open(filename, mode)
@@ -81,6 +78,7 @@ class connector_iterator():
             raise StopIteration
         return data
 
+
 @implementer(IPublishTraverse)
 class RawConnector(BrowserView):
     def __init__(self, context, request):
@@ -152,8 +150,7 @@ class RawConnector(BrowserView):
             LOG.debug(msg)
             raise zExceptions.NotFound()
         except fs.errors.PermissionDeniedError as e:
-            msg = 'eXist-db path {} unauthorized access (check credentials)'.format(
-                e.url)
+            msg = 'eXist-db path {} unauthorized access (check credentials)'.format(e.url)
             self.context.plone_utils.addPortalMessage(msg, 'error')
             LOG.error(msg)
             raise zExceptions.Unauthorized()
@@ -163,8 +160,6 @@ class RawConnector(BrowserView):
         self.traversal_subpath.append(entryname)
         traversal_subpath = '/'.join(self.traversal_subpath)
         handle = self.get_handle()
-        if six.PY2:
-            traversal_subpath = unicode(traversal_subpath, 'utf8')
         if handle.exists(traversal_subpath):
             if handle.isdir(traversal_subpath):
                 return self
@@ -215,13 +210,16 @@ class Connector(RawConnector):
 
     def __call__(self, *args, **kw):
 
+        if '@@connector-view' in self.request.URL:
+            return self.template()
+
         dispatcher = queryUtility(IViewDispatcher)
         if dispatcher:
+            url = None
             try:
                 url = dispatcher(self.context).get_url()
             except Exception as e:
                 LOG.warn('Calling view dispatcher failed', exc_info=True)
-                url = None
             if url:
                 return self.request.response.redirect(url)
         return self.template()
@@ -250,14 +248,10 @@ class Connector(RawConnector):
 
     def folder_contents(self, subpath='.'):
         """" REST endpoint  """
-
         def sort_key(item):
             key = 'A-' if item.is_dir else 'B-'
             return key + item.name
 
-        if six.PY2:
-            subpath = safe_unicode(subpath)
-
         connector_url = self.context.get_connector_url(subpath)
         f = furl.furl(connector_url)
 
@@ -305,8 +299,16 @@ class Connector(RawConnector):
             handle = self.context.get_handle(subpath)
             entries = list(handle.filterdir('.', namespaces=['basic', 'access', 'details']))
             result = []
-            for row in sorted(entries, key=sort_key):
 
+            try:
+                sorted_entries = sorted(entries, key=sort_key)
+            except TypeError:
+                LOG.error('Unable to sort entries', exc_info=True)
+                # Workaround for mod_dav
+                # https://github.com/zopyx/xmldirector.connector/issues/64
+                sorted_entries = entries
+
+            for row in sorted_entries:
                 mimetype, _ = mimetypes.guess_type(row.name)
                 basename, ext = os.path.splitext(row.name)
 
@@ -318,16 +320,10 @@ class Connector(RawConnector):
                 size = modified = ''
                 if 'details' in row.namespaces:
                     size = row.size
-                    if six.PY2:
-                        try:
-                            modified = time.mktime(row.modified.timetuple())
-                        except AttributeError:
-                            modified = u''
-                    else:
-                        try:
-                            modified = row.modified.timestamp()
-                        except AttributeError:
-                            modified = u''
+                    try:
+                        modified = row.modified.timestamp()
+                    except AttributeError:
+                        modified = u''
 
                 is_text = self._is_text(mimetype)
 
@@ -354,16 +350,15 @@ class Connector(RawConnector):
             full_path = fs.path.join(*fs.path.parts(subpath)[:-1])
             result.insert(
                 0,
-                dict(
-                    full_path=full_path,
-                    name='..',
-                    is_file=False,
-                    is_dir=True,
-                    size=0,
-                    mimetype=None,
-                    user='',
-                    group='',
-                    can_remove=False))
+                dict(full_path=full_path,
+                     name='..',
+                     is_file=False,
+                     is_dir=True,
+                     size=0,
+                     mimetype=None,
+                     user='',
+                     group='',
+                     can_remove=False))
 
         self.request.response.setHeader('content-type', 'application/json')
         return json.dumps(result)
@@ -499,8 +494,8 @@ class Connector(RawConnector):
             LOG.error(msg, exc_info=True)
             return self.redirect(msg, 'error')
 
-        self.logger.log(
-            'ZIP file imported ({}, {} files)'.format(zip_file, len(imported_files)), details=imported_files)
+        self.logger.log('ZIP file imported ({}, {} files)'.format(zip_file, len(imported_files)),
+                        details=imported_files)
         return self.redirect(_(u'Uploaded ZIP archive imported'), subpath=subpath)
 
     def zip_import(self, zip_file=None):
@@ -576,4 +571,3 @@ class Connector(RawConnector):
         with open(zip_name, 'rb') as fp:
             self.request.response.write(fp.read())
         os.unlink(zip_name)
-
